@@ -23,6 +23,8 @@ package Sidef::Deparse::Perl {
             namespaces  => [],
             opt         => {},
 
+            environment_name => 'main',
+
             assignment_ops => {
                                '=' => '=',
                               },
@@ -71,7 +73,7 @@ HEADER
 
         if (exists $opts{opt}{P}) {
             my $precision = abs(int($opts{opt}{P}));
-            $opts{header} .= "local \$Sidef::Types::Number::Number::PREC = $precision;\n";
+            $opts{header} .= "local \$Sidef::Types::Number::Number::PREC = 4*$precision;\n";
         }
 
         if (exists $opts{opt}{M}) {
@@ -86,7 +88,7 @@ HEADER
             elsif ($round eq '-inf') {
                 $round = 3;
             }
-            elsif ($round eq '+zero') {
+            elsif ($round eq 'inf') {    # away from zero
                 $round = 4;
             }
             else {
@@ -112,7 +114,7 @@ HEADER
             $self->{before} .= "use constant {\n";
         }
 
-        '(main::' . (
+        '(' . $self->{environment_name} . '::' . (
             (
              $const{$ref, $#args, @args} //= [
                  $name . @args,
@@ -627,7 +629,7 @@ HEADER
         }
         elsif ($ref eq 'Sidef::Variable::Define') {
             my $name  = $obj->{name} . $refaddr;
-            my $value = '(' . 'main::' . $name . ')';
+            my $value = '(' . $self->{environment_name} . '::' . $name . ')';
             if (not exists $obj->{inited}) {
                 $obj->{inited} = 1;
                 $self->top_add('use constant ' . $name . ' => ' . 'do {' . $self->deparse_script($obj->{expr}) . " };\n");
@@ -1368,12 +1370,16 @@ HEADER
                     # != and == methods
                     if ($method eq '==' or $method eq '!=') {
                         $code =
-                            '(('
-                          . ($method eq '!=' ? 'CORE::not ' : '') . 'do{'
+                            '(' . 'do{'
                           . $code
                           . '} eq do{'
-                          . $self->deparse_args(@{$call->{arg}})
-                          . '}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
+                          . $self->deparse_args(@{$call->{arg}}) . '} ? '
+                          . (
+                             $method eq '!='
+                             ? '(Sidef::Types::Bool::Bool::FALSE) : (Sidef::Types::Bool::Bool::TRUE)'
+                             : '(Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE)'
+                            )
+                          . ')';
                         next;
                     }
 
@@ -1393,12 +1399,16 @@ HEADER
                     if ($method eq '~~' or $method eq '!~') {
                         $self->top_add(qq{use experimental 'smartmatch';\n});
                         $code =
-                            '(('
-                          . ($method eq '!~' ? 'CORE::not ' : '') . 'do{'
+                            '(' . 'do{'
                           . $code
                           . '} ~~ do{'
-                          . $self->deparse_args(@{$call->{arg}})
-                          . '}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE))';
+                          . $self->deparse_args(@{$call->{arg}}) . '} ? '
+                          . (
+                             $method eq '!~'
+                             ? '(Sidef::Types::Bool::Bool::FALSE) : (Sidef::Types::Bool::Bool::TRUE)'
+                             : '(Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE)'
+                            )
+                          . ')';
                         next;
                     }
 
