@@ -269,6 +269,65 @@ package Sidef::Types::Array::Array {
     *lev   = \&levenshtein;
     *leven = \&levenshtein;
 
+    sub jaro_distance {
+        my ($self, $arg, $winkler) = @_;
+
+        my @s = @{$self};
+        my @t = @{$arg};
+
+        my $s_len = @s;
+        my $t_len = @t;
+
+        if ($s_len == 0 and $t_len == 0) {
+            return 1;
+        }
+
+        state $x = require List::Util;
+        my $match_distance = int(List::Util::max($s_len, $t_len) / 2) - 1;
+
+        my @s_matches;
+        my @t_matches;
+
+        my $matches = 0;
+        foreach my $i (0 .. $#s) {
+
+            my $start = List::Util::max(0, $i - $match_distance);
+            my $end = List::Util::min($i + $match_distance + 1, $t_len);
+
+            foreach my $j ($start .. $end - 1) {
+                $t_matches[$j] and next;
+                $s[$i] eq $t[$j] or next;
+                $s_matches[$i] = 1;
+                $t_matches[$j] = 1;
+                $matches++;
+                last;
+            }
+        }
+
+        return Sidef::Types::Number::Number::ZERO if $matches == 0;
+
+        my $k              = 0;
+        my $transpositions = 0;
+
+        foreach my $i (0 .. $#s) {
+            $s_matches[$i] or next;
+            while (not $t_matches[$k]) { ++$k }
+            $s[$i] eq $t[$k] or ++$transpositions;
+            ++$k;
+        }
+
+        my $jaro = (($matches / $s_len) + ($matches / $t_len) + (($matches - $transpositions / 2) / $matches)) / 3;
+
+        $winkler || return Sidef::Types::Number::Number->new($jaro);    # return the Jaro distance instead of Jaro-Winkler
+
+        my $prefix = 0;
+        foreach my $i (0 .. List::Util::min(3, $#t, $#s)) {
+            $s[$i] eq $t[$i] ? ++$prefix : last;
+        }
+
+        Sidef::Types::Number::Number->new($jaro + $prefix * 0.1 * (1 - $jaro));
+    }
+
     sub combinations {
         my ($self, $k, $block) = @_;
 
@@ -869,9 +928,8 @@ package Sidef::Types::Array::Array {
         my ($self, $code) = @_;
 
         foreach my $val (@{$self}) {
-            if ($code->run($val)) {
-                return (Sidef::Types::Bool::Bool::TRUE);
-            }
+            $code->run($val)
+              && return (Sidef::Types::Bool::Bool::TRUE);
         }
 
         (Sidef::Types::Bool::Bool::FALSE);
@@ -883,9 +941,8 @@ package Sidef::Types::Array::Array {
         @{$self} || return (Sidef::Types::Bool::Bool::FALSE);
 
         foreach my $val (@{$self}) {
-            if (not $code->run($val)) {
-                return (Sidef::Types::Bool::Bool::FALSE);
-            }
+            $code->run($val)
+              || return (Sidef::Types::Bool::Bool::FALSE);
         }
 
         (Sidef::Types::Bool::Bool::TRUE);
@@ -1065,7 +1122,18 @@ package Sidef::Types::Array::Array {
 
     sub range {
         my ($self) = @_;
-        Sidef::Types::Range::RangeNumber->__new__(from => 0, to => $#{$self}, step => 1);
+        Sidef::Types::Range::RangeNumber->__new__(
+            from => ${(Sidef::Types::Number::Number::ZERO)},
+            to   => do {
+                my $r = Math::GMPq::Rmpq_init();
+                my $i = $#{$self};
+                $i < 0
+                  ? Math::GMPq::Rmpq_set_si($r, $i, 1)
+                  : Math::GMPq::Rmpq_set_ui($r, $i, 1);
+                $r;
+            },
+            step => ${(Sidef::Types::Number::Number::ONE)},
+                                                 );
     }
 
     sub indices {
@@ -1516,7 +1584,7 @@ package Sidef::Types::Array::Array {
 
     sub push {
         my ($self, @args) = @_;
-        push @{$self}, @{$self->new(@args)};
+        CORE::push(@{$self}, @args);
         $self;
     }
 
@@ -1524,7 +1592,7 @@ package Sidef::Types::Array::Array {
 
     sub unshift {
         my ($self, @args) = @_;
-        CORE::unshift(@{$self}, @{$self->new(@args)});
+        CORE::unshift(@{$self}, @args);
         $self;
     }
 
