@@ -6,6 +6,11 @@ package Sidef::Types::Block::Block {
       Sidef::Convert::Convert
       );
 
+    use overload
+      q{bool} => sub { 1 },
+      q{""}   => sub { "$_[0]->{code}" =~ s{^CODE}{Sidef::normalize_type($_[0]->{name} // '__BLOCK__')}er },
+      q{0+}   => sub { state $x = require Scalar::Util; Scalar::Util::refaddr($_[0]) };
+
     sub new {
         my (undef, %opt) = @_;
         bless \%opt, __PACKAGE__;
@@ -302,14 +307,14 @@ package Sidef::Types::Block::Block {
     }
 
     sub fork {
-        my ($self) = @_;
+        my ($self, @args) = @_;
 
         my $fork = Sidef::Types::Block::Fork->new();
 
         my $pid = CORE::fork() // die "[ERROR] Cannot fork: $!";
         if ($pid == 0) {
             srand();
-            $self->{code}->();
+            $self->call(@args);
             exit 0;
         }
 
