@@ -101,7 +101,7 @@ package Sidef::Types::Number::Complex {
                     return __PACKAGE__->new($x, __PACKAGE__->new($re, $im));
                 }
                 else {
-                    return __PACKAGE__->new($x, __PACKAGE__->new(0, $y));
+                    return __PACKAGE__->new($x, __PACKAGE__->new(0, substr($y, 0, -1)));
                 }
             }
         }
@@ -142,10 +142,6 @@ package Sidef::Types::Number::Complex {
 
     *call = \&new;
 
-    sub _new {
-        bless \$_[0], __PACKAGE__;
-    }
-
     sub _valid {
         (
          ref($_) eq __PACKAGE__
@@ -215,7 +211,7 @@ package Sidef::Types::Number::Complex {
         Math::MPFR::Rmpfr_const_pi($pi, $Sidef::Types::Number::Number::ROUND);
         my $cplx_pi = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_set_fr($cplx_pi, $pi, $ROUND);
-        _new($cplx_pi);
+        bless(\$cplx_pi, __PACKAGE__);
     }
 
     sub e {
@@ -224,14 +220,14 @@ package Sidef::Types::Number::Complex {
         Math::MPFR::Rmpfr_exp($e, $one_f, $Sidef::Types::Number::Number::ROUND);
         my $cplx_e = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_set_fr($cplx_e, $e, $ROUND);
-        _new($cplx_e);
+        bless(\$cplx_e, __PACKAGE__);
     }
 
     sub i {
         state $i = do {
             my $r = Math::MPC::Rmpc_init2($PREC);
             Math::MPC::Rmpc_set_ui_ui($r, 0, 1, $ROUND);
-            _new($r);
+            bless(\$r, __PACKAGE__);
         };
     }
 
@@ -247,7 +243,7 @@ package Sidef::Types::Number::Complex {
 
         my $cplx_phi = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_set_fr($cplx_phi, $phi, $ROUND);
-        _new($cplx_phi);
+        bless(\$cplx_phi, __PACKAGE__);
     }
 
     #
@@ -257,13 +253,13 @@ package Sidef::Types::Number::Complex {
     sub abs {
         my $mpfr = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_abs($mpfr, ${$_[0]}, $ROUND);
-        Sidef::Types::Number::Number::_mpfr2rat($mpfr);
+        Sidef::Types::Number::Number::_mpfr2big($mpfr);
     }
 
     sub norm {
         my $mpfr = Math::MPFR::Rmpfr_init2($PREC);
         Math::MPC::Rmpc_norm($mpfr, ${$_[0]}, $ROUND);
-        Sidef::Types::Number::Number::_mpfr2rat($mpfr);
+        Sidef::Types::Number::Number::_mpfr2big($mpfr);
     }
 
     *reciprocal = \&norm;
@@ -273,7 +269,7 @@ package Sidef::Types::Number::Complex {
         Math::MPC::RMPC_RE($mpfr, ${$_[0]});
 
         #Math::MPC::Rmpc_real($mpfr, ${$_[0]}, $ROUND);
-        Sidef::Types::Number::Number::_mpfr2rat($mpfr);
+        Sidef::Types::Number::Number::_mpfr2big($mpfr);
     }
 
     *re = \&real;
@@ -283,7 +279,7 @@ package Sidef::Types::Number::Complex {
         Math::MPC::RMPC_IM($mpfr, ${$_[0]});
 
         #Math::MPC::Rmpc_imag($mpfr, ${$_[0]}, $ROUND);
-        Sidef::Types::Number::Number::_mpfr2rat($mpfr);
+        Sidef::Types::Number::Number::_mpfr2big($mpfr);
     }
 
     *im        = \&imag;
@@ -293,14 +289,14 @@ package Sidef::Types::Number::Complex {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_neg($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub conj {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_conj($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     *not       = \&conj;
@@ -318,10 +314,10 @@ package Sidef::Types::Number::Complex {
             Math::MPC::Rmpc_add($r, $$x, $$y, $ROUND);
         }
         else {
-            Math::MPC::Rmpc_add_fr($r, $$x, $y->_as_float(), $ROUND);
+            Math::MPC::Rmpc_add_fr($r, $$x, $y->_big2mpfr(), $ROUND);
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub sub {
@@ -332,10 +328,10 @@ package Sidef::Types::Number::Complex {
             Math::MPC::Rmpc_sub($r, $$x, $$y, $ROUND);
         }
         else {
-            Math::MPC::Rmpc_add_fr($r, $$x, -$y->_as_float(), $ROUND);
+            Math::MPC::Rmpc_add_fr($r, $$x, -$y->_big2mpfr(), $ROUND);
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub mul {
@@ -346,10 +342,10 @@ package Sidef::Types::Number::Complex {
             Math::MPC::Rmpc_mul($r, $$x, $$y, $ROUND);
         }
         else {
-            Math::MPC::Rmpc_mul_fr($r, $$x, $y->_as_float(), $ROUND);
+            Math::MPC::Rmpc_mul_fr($r, $$x, $y->_big2mpfr(), $ROUND);
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub div {
@@ -361,10 +357,19 @@ package Sidef::Types::Number::Complex {
             Math::MPC::Rmpc_div($r, $$x, $$y, $ROUND);
         }
         else {
-            Math::MPC::Rmpc_div_fr($r, $$x, $y->_as_float(), $ROUND);
+            Math::MPC::Rmpc_div_fr($r, $$x, $y->_big2mpfr(), $ROUND);
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
+    }
+
+    sub inv {
+        my ($x) = @_;
+
+        my $r = Math::MPC::Rmpc_init2($PREC);
+        Math::MPC::Rmpc_ui_div($r, 1, $$x, $ROUND);
+
+        bless(\$r, __PACKAGE__);
     }
 
     sub pow {
@@ -375,30 +380,35 @@ package Sidef::Types::Number::Complex {
             Math::MPC::Rmpc_pow($r, $$x, $$y, $ROUND);
         }
         else {
-            Math::MPC::Rmpc_pow_fr($r, $$x, $y->_as_float(), $ROUND);
+            Math::MPC::Rmpc_pow_fr($r, $$x, $y->_big2mpfr(), $ROUND);
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub root {
         my ($x, $y) = @_;
-        state $one = __PACKAGE__->new(1);
-        return $x->pow($one->div($y));
+        return $x->pow($y->inv);
     }
 
     sub sqrt {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sqrt($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub cbrt {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
-        Math::MPC::Rmpc_pow_d($r, $$x, 1 / 3, $ROUND);
-        _new($r);
+        state $three_inv = do {
+            my $r = Math::MPC::Rmpc_init2($PREC);
+            Math::MPC::Rmpc_set_ui($r, 3, $ROUND);
+            Math::MPC::Rmpc_ui_div($r, 1, $r, $ROUND);
+            $r;
+        };
+        Math::MPC::Rmpc_pow($r, $$x, $three_inv, $ROUND);
+        bless(\$r, __PACKAGE__);
     }
 
     sub log {
@@ -413,20 +423,20 @@ package Sidef::Types::Number::Complex {
                 Math::MPC::Rmpc_div($r, $r, $baseln, $ROUND);
             }
             else {
-                my $baseln = Math::MPFR::Rmpfr_init2($PREC);
-                Math::MPFR::Rmpfr_log($baseln, $y->_as_float(), $Sidef::Types::Number::Number::ROUND);
+                my $baseln = $y->_big2mpfr();
+                Math::MPFR::Rmpfr_log($baseln, $baseln, $Sidef::Types::Number::Number::ROUND);
                 Math::MPC::Rmpc_div_fr($r, $r, $baseln, $ROUND);
             }
         }
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub ln {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_log($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub log2 {
@@ -440,21 +450,21 @@ package Sidef::Types::Number::Complex {
         Math::MPFR::Rmpfr_log($baseln, $two, $Sidef::Types::Number::Number::ROUND);
         Math::MPC::Rmpc_div_fr($r, $r, $baseln, $ROUND);
 
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub log10 {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_log10($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub exp {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_exp($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub exp2 {
@@ -462,7 +472,7 @@ package Sidef::Types::Number::Complex {
         state $two = Math::MPC->new(2);
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_pow($r, $two, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub exp10 {
@@ -470,7 +480,7 @@ package Sidef::Types::Number::Complex {
         state $ten = Math::MPC->new(10);
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_pow($r, $ten, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub dec {
@@ -478,7 +488,7 @@ package Sidef::Types::Number::Complex {
         state $one = Math::MPC->new(1);
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sub($r, $$x, $one, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub inc {
@@ -486,7 +496,7 @@ package Sidef::Types::Number::Complex {
         state $one = Math::MPC->new(1);
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_add($r, $$x, $one, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -497,84 +507,84 @@ package Sidef::Types::Number::Complex {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sin($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub asin {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_asin($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub sinh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sinh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub asinh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_asinh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub cos {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_cos($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub acos {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_acos($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub cosh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_cosh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub acosh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_acosh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub tan {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_tan($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub atan {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_atan($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub tanh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_tanh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     sub atanh {
         my ($x) = @_;
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_atanh($r, $$x, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -586,7 +596,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sin($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -598,7 +608,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_asin($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -610,7 +620,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_sinh($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -622,7 +632,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_asinh($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -634,7 +644,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_cos($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -646,7 +656,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_acos($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -658,7 +668,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_cosh($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -670,7 +680,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_acosh($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -682,7 +692,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_tan($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -694,7 +704,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_atan($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -706,7 +716,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_tanh($r, $$x, $ROUND);
         Math::MPC::Rmpc_div($r, $one, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -718,7 +728,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $one, $$x, $ROUND);
         Math::MPC::Rmpc_atanh($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -737,7 +747,7 @@ package Sidef::Types::Number::Complex {
         my $r = Math::MPC::Rmpc_init2($PREC);
         Math::MPC::Rmpc_div($r, $$x, $$y, $ROUND);
         Math::MPC::Rmpc_atan($r, $r, $ROUND);
-        _new($r);
+        bless(\$r, __PACKAGE__);
     }
 
     #
@@ -853,11 +863,13 @@ package Sidef::Types::Number::Complex {
         $_[0]->abs->ceil;
     }
 
-    sub roundf {
+    sub round {
         my ($x, $prec) = @_;
-        $x->abs->roundf($prec);
+        $x->abs->round($prec);
     }
 
+    *roundf = \&round;
+
     sub is_zero {
         $_[0]->abs->is_zero;
     }
