@@ -78,12 +78,16 @@ package Sidef::Types::Number::Inf {
     *is_odd    = \&is_ninf;
     *divides   = \&is_ninf;
     *is_real   = \&is_ninf;
+    *is_zero   = \&is_ninf;
+    *is_one    = \&is_ninf;
+    *is_mone   = \&is_ninf;
 
     sub nan {
         state $x = Sidef::Types::Number::Nan->new;
     }
 
     *mod         = \&nan;
+    *imod        = \&nan;
     *fmod        = \&nan;
     *bin         = \&nan;
     *modpow      = \&nan;
@@ -127,6 +131,15 @@ package Sidef::Types::Number::Inf {
     *neg = \&ninf;
     *not = \&ninf;
 
+    sub root {
+        my ($x, $y) = @_;
+        ref($y) eq 'Sidef::Types::Number::Inf' || ref($y) eq 'Sidef::Types::Number::Ninf' ? Sidef::Types::Number::Number::ONE
+          : $y->is_neg ? Sidef::Types::Number::Number::ZERO
+          :              $x->inf();
+    }
+
+    *iroot = \&root;
+
     sub min { $_[1] }
     sub inf { $_[0] }
 
@@ -135,8 +148,6 @@ package Sidef::Types::Number::Inf {
     *sqrt             = \&inf;
     *isqrt            = \&inf;
     *cbrt             = \&inf;
-    *root             = \&inf;
-    *iroot            = \&inf;
     *sqr              = \&inf;
     *log              = \&inf;
     *log2             = \&inf;
@@ -189,12 +200,16 @@ package Sidef::Types::Number::Inf {
     *deg2rad          = \&inf;
     *grad2rad         = \&inf;
     *grad2deg         = \&inf;
+    *round            = \&inf;
+    *roundf           = \&inf;
 
     sub zero { (Sidef::Types::Number::Number::ZERO) }
 
-    *inv   = \&zero;
-    *sin   = \&zero;
-    *cos   = \&zero;
+    *inv = \&zero;
+
+    *sin = \&nan;    # -1 to 1
+    *cos = \&nan;    # -1 to 1
+
     *sech  = \&zero;
     *csch  = \&zero;
     *acsc  = \&zero;
@@ -225,12 +240,12 @@ package Sidef::Types::Number::Inf {
     #
     ## asin(inf) = -inf*i
     #
-    sub asin { state $x = Sidef::Types::Number::Complex->new(0, '-@inf@') }
+    sub asin { state $x = Sidef::Types::Number::Complex->new(0, '-@Inf@') }
 
     #
     ## acos(inf) = inf*i
     #
-    sub acos { state $x = Sidef::Types::Number::Complex->new(0, '@inf@') }
+    sub acos { state $x = Sidef::Types::Number::Complex->new(0, '@Inf@') }
 
     #
     ## atan(inf) = pi/2
@@ -269,6 +284,7 @@ package Sidef::Types::Number::Inf {
         my ($x, $y) = @_;
         ref($y) eq 'Sidef::Types::Number::Inf' ? (Sidef::Types::Number::Number::ONE)
           : $y->is_neg                         ? (Sidef::Types::Number::Number::ZERO)
+          : $y->is_zero                        ? (Sidef::Types::Number::Number::ONE)
           :                                      $x;
     }
 
@@ -277,9 +293,28 @@ package Sidef::Types::Number::Inf {
     sub times {
         my ($x, $block) = @_;
 
-        my $i = 0;
+        my $i = Math::GMPz::Rmpz_init_set_ui(1);
         while (1) {
-            if (defined(my $res = $block->_run_code(Sidef::Types::Number::Number::_new_uint(++$i)))) {
+            my $num = Math::GMPq::Rmpq_init();
+            Math::GMPq::Rmpq_set_z($num, $i);
+            Math::GMPz::Rmpz_add_ui($i, $i, 1);
+            if (defined(my $res = $block->_run_code(bless \$num, 'Sidef::Types::Number::Number'))) {
+                return $res;
+            }
+        }
+
+        $block;
+    }
+
+    sub itimes {
+        my ($x, $block) = @_;
+
+        my $i = Math::GMPz::Rmpz_init_set_ui(0);
+        while (1) {
+            my $num = Math::GMPq::Rmpq_init();
+            Math::GMPq::Rmpq_set_z($num, $i);
+            Math::GMPz::Rmpz_add_ui($i, $i, 1);
+            if (defined(my $res = $block->_run_code(bless \$num, 'Sidef::Types::Number::Number'))) {
                 return $res;
             }
         }
@@ -289,7 +324,18 @@ package Sidef::Types::Number::Inf {
 
     sub pow {
         my ($x, $y) = @_;
-        $y->is_neg ? (Sidef::Types::Number::Number::ZERO) : $y->is_zero ? (Sidef::Types::Number::Number::ONE) : $x;
+
+        if (ref($y) eq 'Sidef::Types::Number::Nan') {
+            return $y;
+        }
+
+            $y->is_neg  ? (Sidef::Types::Number::Number::ZERO)
+          : $y->is_zero ? (Sidef::Types::Number::Number::ONE)
+          :               $x;
+    }
+
+    sub ipow {
+        $_[0]->pow($_[1]->int);
     }
 
     #
