@@ -12,6 +12,8 @@ package Sidef::Types::Regex::Match {
       Sidef::Object::Object
       );
 
+    use Sidef::Types::Bool::Bool;
+
     sub new {
         my (undef, %hash) = @_;
 
@@ -68,7 +70,7 @@ package Sidef::Types::Regex::Match {
     }
 
     sub matched {
-        Sidef::Types::Bool::Bool->new($_[0]->{matched});
+        ($_[0]->{matched}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     *to_bool       = \&matched;
